*************************************************************************************
*														*
*	Bitmap image manipulation for the EASy68k simulator	2006/01/10			*
*														*
*	This code shows how a bitmap can be rendered at any rotation and zoom just	*
*	using fixed point maths. The bitmap is a 24bit colour 64 x 64 pixel image	*
*	rendered 256 x 256 using 4 x 4 pixek blocks.						*
*														*
*	[I] and [M] move the image origin up and down, [J] and [K] move the image	*
*	origin left and right. [W] zooms out, [Z] zooms in, [A] rotates the image	*
*	anticlockwise and [S] rotates the image clockwise.					*
*														*
*	This version for Sim68K 3.2 or later							*
*														*
*	More 68000 and other projects can be found on my website at ..			*
*														*
*	 http://www.themotionstore.com/leeedavison/index.html					*
*														*
*	.. or ..												*
*														*
*	 http://members.lycos.co.uk/leeedavison/index.html					*
*														*
*	mail : leeedavison@lycos.co.uk								*
*														*
*************************************************************************************

	ORG	$1000

start
	BSR		Initialise			* go setup stuff

	MOVE.b	#17,d1			* enable double buffering
	MOVE.b	#92,d0			* set draw mode
	TRAP		#15

	MOVE.b	#11,d0			* position cursor
	MOVE.w	#$FF00,d1			* clear screen
	TRAP		#15

* the main loop, after the setup is complete everything is called from within this code

loop
	MOVE.b	#94,d0			* copy screen buffer to main
	TRAP		#15

	MOVEQ		#8,d0				* get time in 1/100 ths seconds
	TRAP		#15

	MOVE.l	d1,-(sp)			* push time on the stack

	MOVE.b	#11,d0			* position cursor
	MOVE.w	#$FF00,d1			* clear screen buffer
	TRAP		#15

	BSR.s		c_controls			* go check the keys
	BSR		draw_bitmap			* draw the new image

* now wait for a while. if you have a slow machine this shouldn't slow it down much but
* if you have a fast machine them this will stop the effect running too fast

	MOVE.l	(sp)+,d7			* restore time in 1/100 ths from stack
wait_100ms
	MOVEQ		#8,d0				* get time in 1/100 ths seconds
	TRAP		#15

	SUB.l		d7,d1				* subtract previous time from current time
	CMP.b		#$09,d1			* compare with 9/100ths
	BMI.s		wait_100ms			* loop if time not up yet

* if you want to see how fast it can go comment out the BMI.s above

	BRA.s		loop				* loop forever

*************************************************************************************
*
* check the keys. [I] and [M] move the origin up and down, [J] and [K] move the origin
* left and right. [W] zooms out, [Z] zooms in, [A] rotates the image anticlockwise and
* [S] rotates the image clockwise

c_controls
	MOVE.l	#'IJKM',d1			* move origin keys
	MOVE.b	#19,d0			* check for keypress
	TRAP		#15

	MOVEQ		#$3F,d2			* set origin mask
	TST.l		d1				* test 'I'
	BEQ.s		not_m				* skip all if no key set

	BPL.s		not_i				* branch if not 'I'

	ADDQ.w	#1,offsety(a3)		* increment y origin
not_i
	BTST		#23,d1			* test 'J'
	BEQ.s		not_j				* branch if not 'J'

	ADDQ.w	#1,offsetx(a3)		* increment x origin
not_j
	TST.w		d1				* test 'K'
	BPL.s		not_k				* branch if not 'K'

	SUBQ.w	#1,offsetx(a3)		* decrement x origin
not_k
	TST.b		d1				* test 'M'
	BPL.s		not_m				* branch if not 'M'

	SUBQ.w	#1,offsety(a3)		* decrement y origin
not_m

* now process zoom and rotate keys

	MOVE.l	#'AWSZ',d1			* adjust keys key
	MOVE.b	#19,d0			* check for keypress
	TRAP		#15

	TST.l		d1				* test 'A'
	BEQ.s		not_w				* skip all if no key set

	BPL.s		not_a				* branch if not 'A'

	MOVE.w	angle(a3),d0		* get angle
	SUB.w		#1,d0				* decrement it
	MOVE.w	d0,angle(a3)		* save it
not_a
	TST.w		d1				* test 'S'
	BPL.s		not_s				* branch if not 'S'

	MOVE.w	angle(a3),d0		* get angle
	ADDQ.w	#1,d0				* increment it
	MOVE.w	d0,angle(a3)		* save it
not_s
	TST.b		d1				* test 'Z'
	BPL.s		not_z				* branch if not 'Z'

	SUB.w		#$40,zoom(a3)		* decrement zoom
not_z
	BTST		#23,d1			* test 'W'
	BEQ.s		not_w				* branch if not 'W'

	ADD.w		#$40,zoom(a3)		* increment zoom
not_w
	RTS

*************************************************************************************
*
* generate the image and display it. first calculate the delta x and delta y from the
* angle and zoom

* the bitmap x and y co-ordinates are 16 bit fixed point numbers of the form
*
*	nnnnnn.ffffffffff
*
* where n are the whole number bits and f are the fractional bits. when accessing the
* bitmap using these fixed point numbers the fractional part is simply discarded which
* results in some aliasing of the image

draw_bitmap
	MOVE.w	zoom(a3),d1			* get zoom

	MOVE.w	angle(a3),d0		* get rotation angle
	BSR		sin_d0			* get sin(angle)
	MOVE.w	d0,d2				* copy sin(angle)
	MULS.w	d1,d0				* * zoom
	SWAP		d0				* only want high word
	MOVE.w	d0,deltay(a3)		* save delta y

	MOVE.w	angle(a3),d0		* get angle
	BSR		cos_d0			* get cos(angle)
	MOVE.w	d0,d3				* copy cos(angle)
	MULS.w	d1,d0				* * zoom
	SWAP		d0				* only want high word
	MOVE.w	d0,deltax(a3)		* save delta x

* origin y = sin(offset y) + cos(offset x)

	MOVE.w	offsety(a3),d0		* get y origin
	MULS.w	d2,d0				* * sin(angle)
	MOVE.l	d0,d4				* copy it
	MOVE.w	offsetx(a3),d0		* get x origin
	MULS.w	d3,d0				* * cos(angle)
	ADD.l		d4,d0				* + sin(y)
	BSR		do16x32			* zoom * origin y
	MOVE.w	d0,d7				* set bitmap origin y

* origin x = sin(offset x) - cos(offset y)

	MOVE.w	offsety(a3),d0		* get y origin
	MULS.w	d3,d0				* * cos(angle)
	MOVE.l	d0,d4				* copy it
	MOVE.w	offsetx(a3),d0		* get x origin
	MULS.w	d2,d0				* * sin(angle)
	SUB.l		d4,d0				* - cos(y)
	BSR		do16x32			* zoom * origin x
	MOVE.w	d0,d6				* set bitmap origin x

* reset the y origin

	MOVE.w	#$3F,d2			* display y = 63
gen_yloop
	SUB.w		deltax(a3),d6		* xb = xb - delta x
	MOVE.w	d6,d4				* xa = xb

	ADD.w		deltay(a3),d7		* yb = yb + delta y
	MOVE.w	d7,d5				* ya = yb

	MOVE.w	#$3F,d1			* display x = 63
gen_xloop
	ADD.w		deltay(a3),d4		* xa = xa + delta y
	ADD.w		deltax(a3),d5		* ya = ya + delta x

	MOVEM.l	d1-d2/d4,-(sp)		* save x1, y1, xa

* calculate the memory address for the bitmap pixel

	MOVE.w	d5,d0				* copy ya
	ROR.w		#2,d0				* top 6 bits to b5 - b0 * 64
	AND.w		#$3F00,d0			* mask image y

	MOVE.w	d4,d1				* copy xa
	LSR.w		#8,d1				* top 6 bits to b7 - b2
	AND.w		#$FC,d1			* mask image x

	OR.w		d1,d0				* add y * 64
	MOVE.l	(a1,d0.w),d1		* get pixel intensity

* now set the colour for this pixel as both the draw and fill colours

	MOVEQ		#80,d0			* set pen colour
	TRAP		#15

	MOVEQ		#81,d0			* set fill colour
	TRAP		#15

	MOVE.l	(sp),d1			* restore x1

* calculate the screen x1 and y1 co-ordinates for this pixel

	ADD.w		d1,d1				* x1 * 2
	ADD.w		d1,d1				* x1 * 4
	ADD.w		#32,d1			* x1 * 4 + 32
	ADD.w		d2,d2				* y1 * 2
	ADD.w		d2,d2				* y1 * 4
	ADD.w		#32,d2			* y1 * 4 + 32

* calculate the screen x2 and y2 co-ordinates for this pixel

	MOVE.w	d1,d3				* x2 = x1
	ADDQ.w	#4,d3				* x2 = x1 + 4 make small square
	MOVE.w	d2,d4				* y2 = y1
	ADDQ.w	#4,d4				* y2 = y1 + 4 make small square

* now draw pixel

	MOVEQ		#87,d0			* draw rectangle
	TRAP		#15				* do draw

	MOVEM.l	(sp)+,d1-d2/d4		* restore x1, y1, xa

	DBF		d1,gen_xloop		* decrement x1 and loop for next

	DBF		d2,gen_yloop		* decrement y1 and loop for next

	RTS

*************************************************************************************
*
* 16 * 32 bit signed multiply d1 * d0

do16x32
	MOVE.l	d0,-(sp)			* save the sign flag
	BPL.s		notneg			* branch if +ve

	NEG.l		d0				* negate d0
notneg
	MOVE.w	d0,d4				* copy low word to low word d4
	SWAP		d0				* copy high word to low word d0

							* multiply low word
	MULU.w	d1,d4				* low word * zoom
	CLR.w		d4				* clear low word
	SWAP		d4				* only want high word

							* multiply high word
	MULU.w	d1,d0				* high word * zoom
	ADD.l		d4,d0				* add low word result

							* now set sign
	TST.l		(sp)+				* restore the sign flag
	BPL.s		negnot			* branch if was +ve

	NEG.l		d0				* negate d0
negnot
	ASR.l		#1,d0				* result / 2
	RTS

*************************************************************************************
*
* setup stuff. set the pointer, zoom, angle and origin

Initialise
	LEA		LAB_VARS(pc),a3		* get pointer to variables

	LEA		bitmap(pc),a1		* get pointer to bitmap

	MOVE.w	#0,offsetx(a3)		* set x origin
	MOVE.w	#0,offsety(a3)		* set y origin

	MOVE.w	#$800,zoom(a3)		* set zoom
	MOVE.w	#$80,angle(a3)		* set angle

	RTS

*************************************************************************************
*
* get COS(d0) in d0. d0 is a nine bit value representing a full circle with the value
* increasing as you turn widdershins

cos_d0
	ADD.w		#$80,d0			* add 1/4 rotation

*************************************************************************************
*
* get SIN(d0) in d0. d0 is a nine bit value representing a full circle with the value
* increasing as you turn widdershins

sin_d0
	BTST		#8,d0				* test angle sign
	BEQ.s		cossin_d0			* just get SIN/COS and return if +ve

	BSR.s		cossin_d0			* else get SIN/COS
	NEG.w		d0				* now do twos complement
	RTS

* get d0 from SIN/COS table

cossin_d0
	TST.b		d0				* test for >= $80
	BPL.s		a_was_less			* branch if < 1/4 circle

	NEG.b		d0				* wrap $81 to $FF to $7F to $01
a_was_less
	AND.w		#$FF,d0			* ensure word high byte clear
	ADD.w		d0,d0				* * 2 bytes per word value
	LEA		sin_cos(pc),a0		* get table base address
	MOVE.w	(a0,d0.w),d0		* get SIN/COS value
	RTS

*************************************************************************************
*
* SIN/COS table, returns values between $0000 and $7FFF. the last value should be
* $8000 but that can cause an overflow in the word length calculations and it's
* easier to fudge the table a bit. no one will ever notice.

sin_cos
	dc.w	$0000,$0192,$0324,$04B6,$0648,$07D9,$096B,$0AFB
	dc.w	$0C8C,$0E1C,$0FAB,$113A,$12C8,$1455,$15E2,$176E
	dc.w	$18F9,$1A83,$1C0C,$1D93,$1F1A,$209F,$2224,$23A7
	dc.w	$2528,$26A8,$2827,$29A4,$2B1F,$2C99,$2E11,$2F87
	dc.w	$30FC,$326E,$33DF,$354E,$36BA,$3825,$398D,$3AF3
	dc.w	$3C57,$3DB8,$3F17,$4074,$41CE,$4326,$447B,$45CD
	dc.w	$471D,$486A,$49B4,$4AFB,$4C40,$4D81,$4EC0,$4FFB
	dc.w	$5134,$5269,$539B,$54CA,$55F6,$571E,$5843,$5964
	dc.w	$5A82,$5B9D,$5CB4,$5DC8,$5ED7,$5FE4,$60EC,$61F1
	dc.w	$62F2,$63EF,$64E9,$65DE,$66CF,$67BD,$68A7,$698C
	dc.w	$6A6E,$6B4B,$6C24,$6CF9,$6DCA,$6E97,$6F5F,$7023
	dc.w	$70E3,$719E,$7255,$7308,$73B6,$7460,$7505,$75A6
	dc.w	$7642,$76D9,$776C,$77FB,$7885,$790A,$798A,$7A06
	dc.w	$7A7D,$7AEF,$7B5D,$7BC6,$7C2A,$7C89,$7CE4,$7D3A
	dc.w	$7D8A,$7DD6,$7E1E,$7E60,$7E9D,$7ED6,$7F0A,$7F38
	dc.w	$7F62,$7F87,$7FA7,$7FC2,$7FD9,$7FEA,$7FF6,$7FFE
	dc.w	$7FFF

*************************************************************************************
*
* bitmap of my house. this is a 64 x 64 twenty four bit bitmap. each of the pixels
* is one longword of data of the form $00BBGGRR where BB, GG and RR are the blue,
* green and red intensity values

bitmap

	dc.l	$676A6F,$7A7D82,$7C7F84,$75787D,$72757A,$797C81,$74777C,$76797E
	dc.l	$787B80,$78797D,$78797D,$78797D,$78797D,$79797F,$737379,$74747A
	dc.l	$74747A,$73757D,$73757D,$70727A,$72747C,$767880,$797A84,$767781
	dc.l	$797A84,$787983,$757680,$767781,$74757F,$767781,$777983,$777983
	dc.l	$787A84,$787A84,$787A84,$757680,$777882,$74757F,$767781,$747680
	dc.l	$747680,$757781,$747680,$70747F,$707381,$707381,$727583,$6E7481
	dc.l	$737A8B,$767D8E,$737A8B,$72798A,$70778A,$70778A,$6D7487,$6E7487
	dc.l	$6D768A,$6C778B,$697488,$6A7589,$667284,$667081,$687081,$636A7B
	dc.l	$727173,$727173,$767577,$767577,$75787D,$74777C,$73767B,$787B80
	dc.l	$74777C,$78797D,$77787C,$77787C,$77787C,$78787E,$76767C,$74747A
	dc.l	$75757B,$72757A,$717479,$74777C,$74777C,$74777C,$74757F,$757680
	dc.l	$757680,$767781,$767781,$787983,$777882,$757680,$71737D,$747680
	dc.l	$747680,$767882,$797B85,$787983,$777882,$777882,$767781,$767880
	dc.l	$71737B,$72747C,$72747C,$73747E,$73757F,$6B6D77,$70727C,$6F717C
	dc.l	$6B707F,$6E7382,$6C7180,$757A89,$6E7082,$707284,$747688,$6F7183
	dc.l	$636A7D,$626C7E,$616B7D,$5F697B,$5F697B,$637282,$6D7788,$676F80
	dc.l	$6E7176,$72757A,$717479,$717479,$74777C,$76797E,$75787D,$75787D
	dc.l	$72757A,$76777B,$77787C,$78797D,$7A7B7F,$77777D,$77777D,$79797F
	dc.l	$76767C,$727579,$6F7276,$717478,$717478,$717479,$72737D,$73747E
	dc.l	$757680,$72737D,$73747E,$72737D,$757680,$757680,$72747E,$6F717B
	dc.l	$73757F,$73757F,$747680,$777882,$777882,$777882,$797A84,$7A7A80
	dc.l	$77777D,$75757B,$74747A,$70727A,$73757D,$72747C,$70727A,$6E707A
	dc.l	$696C7A,$686B79,$6A6D7B,$6D707E,$666D7C,$6C7382,$6C7382,$686F7E
	dc.l	$656D7E,$6C7485,$5C6475,$606879,$5F697A,$5B6B7B,$5F6C7C,$747E8F
	dc.l	$717479,$6F7277,$6F7277,$707378,$696D72,$6F7378,$6B6F74,$74787D
	dc.l	$72767B,$72757D,$74777F,$71747C,$70737B,$71747C,$6C6F77,$787B83
	dc.l	$75777F,$717479,$72757A,$72757A,$6F7277,$74777C,$75747E,$73727C
	dc.l	$71707A,$75747E,$6D6D79,$71717D,$72727E,$70707C,$6F707A,$6D6D79
	dc.l	$686973,$75747D,$707076,$777983,$787A85,$797989,$757587,$72727E
	dc.l	$73737F,$777783,$797985,$727681,$5C626D,$585E69,$4A505B,$525A67
	dc.l	$6A7682,$626D7B,$7A8593,$697482,$556572,$485865,$445461,$4E5D6D
	dc.l	$63707E,$66717F,$6A7583,$6B7684,$6A7785,$697989,$647484,$637282
	dc.l	$6E6F73,$727377,$737478,$747579,$727175,$777378,$736F74,$737276
	dc.l	$636266,$717177,$6D6B71,$6C6A70,$6E6C72,$696C71,$707378,$6E7176
	dc.l	$6F7277,$717177,$707175,$6E6F73,$6F7074,$6E6F73,$6C7075,$6B6F74
	dc.l	$6B6F74,$6D7176,$636772,$696D78,$747883,$6F737E,$666B74,$656B76
	dc.l	$67707E,$626D7B,$576774,$6C7F86,$677A7F,$6A767C,$59656B,$41545B
	dc.l	$60737A,$6C7F86,$6C7F86,$76828E,$707986,$67707D,$747D8A,$6A7682
	dc.l	$6D7A88,$6B7886,$687583,$64717F,$617080,$5F6E7E,$5C6B7B,$5F6E7E
	dc.l	$505D6B,$4A5765,$4C5967,$495664,$44515F,$424F5F,$4A5465,$3C4657
	dc.l	$303135,$393A3E,$35363A,$434448,$585459,$3A3439,$504A4F,$373136
	dc.l	$302C31,$39353A,$2F2B30,$312D32,$3F3B40,$343A3F,$454B50,$494F54
	dc.l	$6B6F74,$63676C,$696C70,$676A6E,$6E7175,$6F7477,$677375,$636C6F
	dc.l	$565F62,$576063,$656F79,$818B95,$68727C,$545D67,$505A64,$4B555F
	dc.l	$5A6874,$4F6375,$5C758F,$4B6576,$344A5C,$415461,$556772,$50636A
	dc.l	$586B72,$61747B,$6A7D85,$6F7D89,$74808C,$6A7682,$707C88,$687480
	dc.l	$5E6C78,$586672,$53616D,$52606C,$4B5866,$4B5866,$4B5866,$485563
	dc.l	$43505E,$455260,$44515F,$424F5D,$404D5B,$424A5B,$404859,$3F4758
	dc.l	$454B56,$5D636E,$575D68,$414752,$474B56,$2D2F3A,$363843,$252732
	dc.l	$5F636E,$616871,$5A606B,$535964,$262C37,$2C3844,$283440,$636F7B
	dc.l	$5D6876,$4B555F,$454F59,$48525C,$505A64,$4B555F,$425259,$4E5A64
	dc.l	$3D4953,$3E4A54,$465760,$45565F,$40515A,$415059,$42525F,$454E57
	dc.l	$475054,$495664,$344861,$8D9BB7,$414F6B,$596D86,$495C77,$324151
	dc.l	$2B3A4A,$415060,$3D4B5D,$43505E,$44525E,$4F5D69,$566470,$596773
	dc.l	$505F68,$495861,$47565F,$4C5B64,$44505C,$505C68,$4B5763,$414D59
	dc.l	$3C4957,$3E4B59,$3B4856,$3D4A58,$3C4957,$384555,$394354,$394354
	dc.l	$546274,$616F82,$586679,$637184,$5D6B7D,$9FADBF,$606E80,$667081
	dc.l	$838C9A,$4E5A66,$434E5C,$525F6D,$495966,$384858,$758595,$516171
	dc.l	$3C4E5F,$364656,$4B5868,$354556,$304050,$455260,$2E3F48,$2C3E49
	dc.l	$334752,$2D404F,$31434E,$2F414C,$334550,$2F414C,$2F3D4F,$364149
	dc.l	$564F52,$3A3D42,$171F2C,$2D333E,$182331,$112433,$253A49,$4E6678
	dc.l	$476074,$3A556A,$314C61,$2A3F4E,$2F404D,$344552,$3A4A57,$384854
	dc.l	$3D4E57,$42535C,$596871,$5E6B73,$59646C,$57636D,$4A5662,$44505C
	dc.l	$455260,$3A4A57,$3A4959,$334353,$384858,$364958,$334655,$324554
	dc.l	$87A0B0,$98B0C6,$6A849C,$001629,$00101F,$2D4454,$001626,$384952
	dc.l	$061315,$1F2D33,$373E4D,$293041,$00000A,$1C212A,$15181D,$12151A
	dc.l	$222835,$14222E,$212635,$0D1D29,$00040B,$2B2C30,$142020,$00100D
	dc.l	$1B3C38,$325D60,$316466,$48797B,$3F6C6F,$3C6568,$395D63,$215555
	dc.l	$4F484B,$263234,$111920,$090B1D,$1C2A3C,$0D2733,$49575D,$445159
	dc.l	$0F2231,$283E50,$27384B,$4E6879,$4C6879,$556D7F,$415769,$304456
	dc.l	$2E4554,$384D5C,$3D4D5D,$404F5F,$44535C,$5E6F78,$748490,$697482
	dc.l	$747D8A,$626E78,$6A7682,$465460,$34404A,$0B161E,$00030C,$000007
	dc.l	$00000E,$3A556A,$5B778F,$000011,$000F1F,$3B5464,$415E6C,$00161C
	dc.l	$4A6B6E,$000208,$4A5765,$212837,$121B24,$403F49,$453E45,$312D33
	dc.l	$151221,$2C3B4B,$0A1122,$21313D,$233536,$1B1C1A,$161818,$1D261C
	dc.l	$002513,$044D37,$005942,$0F644E,$0F5A45,$0F5342,$256355,$166552
	dc.l	$4C534C,$283936,$09121B,$343B4F,$041528,$000E1D,$53616D,$415059
	dc.l	$223544,$00091B,$354555,$122A3E,$3F5971,$6A829A,$6B8399,$465D73
	dc.l	$485F6F,$375060,$253D51,$273F55,$2E4051,$324552,$3B4C55,$374049
	dc.l	$111216,$19181C,$080709,$0F0F0F,$181616,$0D080A,$0B0608,$0C0508
	dc.l	$86A3B2,$526F84,$3A5970,$67889B,$314F62,$7996A5,$45666F,$073033
	dc.l	$6A979A,$19373C,$2F3F4B,$0F131E,$000004,$101B23,$6A7377,$1E292D
	dc.l	$101E2A,$000E1A,$28303D,$00040A,$546C6A,$6B726B,$0D1810,$02210C
	dc.l	$206544,$106E4B,$056243,$1A7052,$025235,$054F33,$0A5032,$0C5A3B
	dc.l	$504E46,$2B2E32,$161329,$3A496A,$00132F,$15324D,$313B59,$2C3B4E
	dc.l	$32445B,$11233A,$303E50,$71849F,$435B79,$3E5876,$486482,$021D38
	dc.l	$5B708C,$647994,$4A6079,$32495F,$344964,$21394F,$223949,$253643
	dc.l	$080A12,$151418,$040000,$18110E,$070000,$0B0D0D,$030506,$0A0E0F
	dc.l	$183746,$17364B,$5E7E95,$5C8092,$16394D,$335360,$57757A,$4E7175
	dc.l	$335860,$1B3339,$070F1C,$1C1E26,$131515,$222730,$04070C,$05080D
	dc.l	$000310,$010C10,$161921,$3E565C,$6C8E8E,$758480,$314C3C,$256B4D
	dc.l	$187957,$248164,$2B846A,$2D866C,$186F55,$1C7359,$2B7C5B,$1F7857
	dc.l	$46504A,$23323B,$1B253D,$122C3C,$00232B,$001B20,$091B2C,$313E5E
	dc.l	$18294A,$011030,$08122A,$2F4160,$00082B,$00183A,$486486,$496588
	dc.l	$1A2E57,$2F4263,$17243E,$253346,$637898,$536F8D,$32506B,$46647D
	dc.l	$1E2D3D,$303845,$0B1116,$07090A,$080507,$201622,$3B313E,$544D5A
	dc.l	$6E8398,$8DA6BA,$19394C,$98BCCE,$597E8C,$87A8B7,$5B7887,$435D6D
	dc.l	$142E3C,$162E3A,$00000A,$08131B,$9FAEB1,$465A55,$0E0C12,$0C151E
	dc.l	$000A0D,$3D4C4F,$302C37,$415D5E,$143F34,$435B49,$447965,$1F6D55
	dc.l	$207D62,$2F836A,$2B8D77,$2F8C71,$328F70,$318E73,$338E6D,$3D8F79
	dc.l	$415146,$373231,$17253B,$152639,$061525,$030E1C,$192432,$1A2737
	dc.l	$254164,$132B49,$273345,$39537B,$1B3571,$123061,$274169,$020F3B
	dc.l	$626689,$5A678D,$7D96B6,$2D4E62,$9BB5DA,$90AACE,$294466,$526E8D
	dc.l	$434E7A,$222D31,$504B54,$2C2239,$1B1821,$18141F,$27242D,$48474B
	dc.l	$223A4C,$688293,$254354,$85A6B6,$4F7280,$9EBECB,$708C97,$415C66
	dc.l	$4C696E,$527670,$203B38,$ACC1C2,$617A7C,$2A4139,$101518,$06191E
	dc.l	$3A4F51,$1A2327,$484750,$233234,$182D2A,$24322C,$437C6D,$196952
	dc.l	$116E4F,$00532F,$18624A,$0F563B,$1F664B,$29745E,$4A8E83,$3F8081
	dc.l	$3F4B4B,$3A3435,$15233A,$010D31,$071032,$020629,$000124,$05132A
	dc.l	$385581,$183257,$3C4C63,$7695BC,$2E508B,$23487A,$436691,$415F8E
	dc.l	$1D4165,$324B75,$2E3E6C,$15234D,$A1B3D2,$52627F,$A2AECA,$48556F
	dc.l	$697384,$303B33,$232A27,$2C3035,$444948,$635E5B,$635F5E,$686868
	dc.l	$627C8C,$6A8494,$97B4C3,$486574,$99B8C7,$7E9CA7,$304D52,$476364
	dc.l	$A6C4BF,$4D7165,$426158,$8AA8A3,$99BCB8,$4F6A60,$687675,$486667
	dc.l	$284542,$5B6D6E,$7C9B9A,$4D6C6B,$586E73,$2B4B50,$40777A,$10534E
	dc.l	$075544,$19644E,$093D36,$1C4A3E,$0C362B,$153F38,$8FB2BF,$9BC8DD
	dc.l	$404651,$3A333A,$1C2B3E,$001126,$020F25,$050C25,$0C132E,$36455F
	dc.l	$415F8E,$1D365E,$303E5B,$2E5278,$325791,$2C598C,$33608C,$46689E
	dc.l	$8AA3D5,$A9C0F0,$476896,$3C6798,$7B9CCD,$1C3D6B,$1C3664,$1B305D
	dc.l	$5A5F62,$847F81,$9E9B9D,$7B7776,$4E4A4F,$1E242F,$303341,$4D495C
	dc.l	$536E7C,$3C5765,$6D8795,$37515F,$607D8B,$627E89,$557074,$4B6663
	dc.l	$C2DCD6,$96B5AE,$96AFAB,$73928B,$365B53,$4B695E,$142B27,$4E7573
	dc.l	$5D7E7A,$9BA5A5,$8DB1AB,$7F9E9D,$B5CBD1,$7EA5B4,$528393,$497E8B
	dc.l	$4A858E,$61989F,$6B98AD,$8DAFBC,$243A40,$2D4047,$203144,$96B8D0
	dc.l	$414754,$342C36,$0D1E33,$041726,$031123,$010821,$00041F,$041028
	dc.l	$4D6894,$1E355B,$242F4A,$3F5F83,$375994,$325C91,$2D5889,$4064A0
	dc.l	$335089,$9CB3E3,$4E6B97,$1A446F,$527DAE,$476F9F,$698AB8,$2F4978
	dc.l	$061125,$393860,$353756,$262535,$1C0A29,$240538,$281C4C,$12224D
	dc.l	$23494E,$456B6D,$3E5F62,$BAD7DE,$738D94,$334A52,$718A8E,$5D7575
	dc.l	$6D8884,$5D7B76,$607A7A,$284340,$77958A,$9DB8AF,$52736C,$759A96
	dc.l	$86A5A2,$0F1217,$606E74,$435E68,$96B7C6,$90BBCE,$4A738C,$6D96AD
	dc.l	$85ADC0,$84AFC0,$7DAFCB,$688DA3,$324252,$323845,$3F4348,$96B3D2
	dc.l	$383D46,$372E2B,$1A253B,$0C101B,$101321,$0D0F21,$101427,$000519
	dc.l	$617090,$1E2F50,$293754,$0F2957,$365691,$2A528D,$325892,$547AB0
	dc.l	$83ADD0,$A8CEEE,$41607F,$2A4766,$B1D6FF,$426394,$7D98CA,$2F4678
	dc.l	$7C96D2,$08079D,$0F049A,$170C6C,$1C0A57,$010F57,$52A7D5,$2CCEEA
	dc.l	$436067,$C1E1E0,$557A72,$7B9F99,$7C999D,$809B9F,$7D999A,$97B3B3
	dc.l	$0F2C29,$7FA099,$5C7878,$526D6A,$466158,$839C9E,$809C9D,$516A6C
	dc.l	$B1C5C6,$607B78,$658182,$7D8F9A,$4E5C6E,$38495C,$516D78,$031520
	dc.l	$121E28,$15222A,$131A33,$5B6576,$24333C,$3D545C,$4D595D,$425B75
	dc.l	$46494D,$342822,$141D31,$273754,$162847,$0D2041,$000022,$000011
	dc.l	$040F2A,$18233E,$1A2037,$021530,$4D698C,$44628B,$4D6C93,$5A75A1
	dc.l	$274383,$213D7D,$3A5696,$2B4787,$214680,$315791,$2D538D,$2D538D
	dc.l	$2E5C92,$0E1A8A,$130D78,$100C57,$120A57,$241A56,$000A2E,$001C26
	dc.l	$5A7179,$1C3936,$8EB0A6,$40625B,$9FBDBE,$799798,$486766,$385756
	dc.l	$274742,$98B8B3,$4D6B66,$88A39F,$91AAA6,$536E6B,$96AFAB,$324843
	dc.l	$6F817A,$4A635F,$6A7F80,$08141E,$000111,$647687,$435E6C,$4A5969
	dc.l	$64687A,$585A6C,$424357,$0B0A13,$11171C,$516069,$556571,$394A5D
	dc.l	$444647,$3F3835,$242B3E,$091C3D,$0B1F42,$001438,$092046,$272E47
	dc.l	$404B66,$232B42,$242638,$050E29,$0B1B3F,$00062F,$071C42,$000C2F
	dc.l	$2B4164,$849DBF,$3C587A,$4A6B8C,$415B8A,$446291,$3E608E,$2D5181
	dc.l	$355C90,$10165F,$281554,$170943,$0B044F,$160E4B,$1A0A40,$210C3D
	dc.l	$315759,$466B69,$4B6A6B,$728F94,$6C878B,$759191,$84A19E,$6C8A85
	dc.l	$7C9A95,$5D7D78,$54736A,$65817B,$6E8686,$59776C,$93AAA5,$BAD0CE
	dc.l	$A8C2C2,$8FA5B1,$727F8F,$6B7684,$586E7A,$395C69,$426678,$637B91
	dc.l	$8A99B3,$606E8A,$667E8A,$232B2B,$060509,$646A7D,$3B4A5D,$444E55
	dc.l	$44474F,$283041,$2F3B53,$1D253C,$202A42,$2A3550,$0A1632,$232940
	dc.l	$202B46,$111C37,$232940,$28375E,$506799,$2E477F,$0E285E,$1B3064
	dc.l	$212E66,$16235B,$25326A,$26356D,$26375E,$04173D,$000A30,$00082E
	dc.l	$00032E,$27265E,$331B61,$3E2863,$31224E,$3C3665,$41396E,$4E3274
	dc.l	$5E8C8D,$265253,$2C4D56,$93ADBD,$BCD2D8,$7E9696,$7B9391,$88A19D
	dc.l	$5F7973,$9AB5B1,$9EB9B0,$819B95,$8CA3A5,$566A75,$5E7081,$394B68
	dc.l	$90ACCE,$88B6D5,$2B4A63,$525E70,$5D6673,$475A62,$1F3D42,$9BB2BA
	dc.l	$5B6D7E,$637A8A,$88919E,$54575B,$00060C,$3B5468,$1C3647,$424B4F
	dc.l	$2F3C4A,$A9BEDD,$08203E,$5F6C8C,$7C8CA3,$52607C,$2F3D5A,$65687D
	dc.l	$8E9FBA,$B9CCED,$637898,$4D698C,$345A84,$2C5685,$496E9A,$5A7DA5
	dc.l	$3A618D,$567BA7,$1C406E,$395A8B,$4F70A2,$506FA2,$3E598C,$41598F
	dc.l	$3A4F7C,$112D50,$1F3761,$46527A,$474154,$5A3F42,$553F3A,$53251D
	dc.l	$071325,$4F6676,$133542,$325461,$2D3D49,$677978,$8EA1A6,$7B8D8E
	dc.l	$6C7E71,$899492,$414D41,$919F99,$3A4952,$70889C,$7C9BB4,$687EA1
	dc.l	$91B0D7,$86AED1,$3D5971,$546671,$536870,$536C7C,$304A58,$91A9B5
	dc.l	$576784,$67788B,$535F5F,$4E5459,$040D16,$303E4A,$485868,$333D4E
	dc.l	$6D768A,$384B66,$9DB9D7,$5B689C,$8EA9B3,$0C1D2A,$42465E,$494152
	dc.l	$ABC7DF,$466183,$496F91,$5E799B,$5D81A9,$264876,$465F87,$495976
	dc.l	$203C5A,$8DACCB,$6F91B5,$6387AF,$678AB5,$456893,$5F82AD,$486A95
	dc.l	$5D7EA5,$3E5F8D,$3B5C8E,$6B88B4,$7689A4,$635452,$825E54,$6A4335
	dc.l	$130E29,$09132B,$647C94,$819DB5,$4C5563,$96A0A0,$111D23,$727B7E
	dc.l	$3A423B,$4B4F50,$4A533E,$717A6D,$060C1F,$7C94B2,$799FBF,$546E92
	dc.l	$8AACD0,$97BFE2,$48677E,$617580,$597078,$4B6474,$112732,$B4C8D3
	dc.l	$55617D,$627181,$495555,$4E5459,$202932,$2B3945,$8A9AAB,$7D8799
	dc.l	$636B82,$5D6F8C,$9EB9DB,$606EA9,$46616F,$2D404D,$21283C,$292231
	dc.l	$385066,$586E91,$7FA8C9,$5D799C,$53789E,$264971,$8CA8CB,$869CB8
	dc.l	$64839C,$63849E,$698DAB,$7699BA,$7898BB,$456588,$7898BB,$6D8BAE
	dc.l	$698AAB,$688AAE,$597AA1,$7493B4,$7D98B2,$343B4A,$574544,$654532
	dc.l	$2A3043,$05192B,$547388,$284A61,$565D6C,$CED3D4,$1C242B,$8D9497
	dc.l	$B1B5AF,$302F31,$595D4A,$505645,$080D16,$4B5976,$6D91AF,$5D7DA0
	dc.l	$9BBFE5,$9AC4E7,$4C6C83,$617782,$344E55,$3F5967,$A6BABF,$9BADB4
	dc.l	$646F85,$4A5660,$384444,$464C51,$121B24,$2A3844,$516B77,$465966
	dc.l	$000C1D,$5A768E,$9CBEDB,$5B679D,$657F8B,$2F3F4B,$4B5164,$241C23
	dc.l	$2C3E4F,$5E7192,$86B0D3,$6585A9,$7FA4C6,$7EA1C3,$799ABB,$6E8EAB
	dc.l	$7A9BB5,$7091AB,$7394AE,$7697B1,$7E9EBB,$82A2BF,$7999B6,$7292AF
	dc.l	$698DAB,$789AB8,$708CAA,$617E99,$63829B,$9DB1CA,$949AA5,$483C36
	dc.l	$131319,$00050E,$121F2D,$000618,$505361,$C8D2D2,$242E35,$7D8689
	dc.l	$BBC5B9,$313635,$363733,$60685E,$111F14,$101022,$7592A7,$426182
	dc.l	$99BEE4,$6F9BC0,$48687F,$4A636D,$9CB8BF,$8EA9B7,$26373A,$647376
	dc.l	$353C50,$2A353D,$2B3737,$31373C,$0B141D,$32404C,$424E58,$343640
	dc.l	$333442,$141F33,$1A2F44,$252D55,$2B4042,$152028,$0D0B1F,$120B10
	dc.l	$101F2F,$7180A1,$7FA9CC,$5A7CA0,$7298B8,$85A9C7,$799EBA,$759BB9
	dc.l	$88A9CA,$7192B3,$6E8DAC,$718FAC,$6A8EAC,$7397B5,$6589A7,$7599B7
	dc.l	$6288A8,$7C99B8,$7C94B0,$708DA8,$7B96B0,$5E6D80,$677689,$707786
	dc.l	$010805,$0D0506,$14181D,$13161E,$545859,$A6ACAB,$2E3530,$717972
	dc.l	$A8AEA9,$1F201E,$28271D,$30312F,$0B0E1D,$2F3345,$708DB4,$3C5F81
	dc.l	$7DA2C4,$96BEE1,$6E8C9F,$505F62,$3C4D50,$95ABB6,$ABB9C5,$797A88
	dc.l	$222B35,$2B2733,$2D3A3C,$25272F,$2B2A34,$3F4851,$273142,$2C2D37
	dc.l	$1A1D22,$000511,$8FA7C5,$637AA0,$4F5E71,$040D10,$0C1512,$131216
	dc.l	$444A57,$5F7793,$6188AF,$4F769C,$7396B7,$6A8CAA,$7B9DBA,$7293AD
	dc.l	$7595B2,$6C8CA9,$7191AE,$7898B5,$7291B0,$7594B3,$7796B5,$7897B6
	dc.l	$6F8BAD,$668AA8,$6F95AD,$88A0B6,$162135,$BCC5D2,$979DA2,$4A4C4D
	dc.l	$0C201B,$161315,$11171C,$0F1821,$12131D,$0B0C16,$101318,$04070B
	dc.l	$000003,$121317,$070505,$373941,$080C1F,$0C1324,$87A4CB,$6E8FB0
	dc.l	$85A7C4,$83A1BE,$243A4C,$6B7E8B,$415B6B,$6D8B9E,$34404C,$889BA0
	dc.l	$011917,$231F1E,$1A2027,$120F18,$100C17,$353B46,$393E4D,$0A0611
	dc.l	$110F15,$00000E,$1E2B45,$3C4C70,$00001D,$0F132B,$0D1025,$131920
	dc.l	$00020B,$000A1C,$869EBA,$527B9C,$7198B8,$7496B4,$7D9BB8,$83A0BB
	dc.l	$6D8DAA,$6D8DAA,$7999B6,$6B8BA8,$7392B1,$6E8DAC,$7190AF,$7796B5
	dc.l	$7894B6,$6E92B0,$577A94,$6C869E,$0C1C39,$526695,$5E6FA7,$737FB9
	dc.l	$3B5E5A,$3F4447,$656F76,$53626B,$4D5465,$585D6C,$5E6471,$353D4A
	dc.l	$464D56,$272A32,$33353D,$1D202E,$1C2637,$1E2735,$A2C0E3,$6D8AA5
	dc.l	$90AFC4,$757F89,$A3AAAD,$ADBFC0,$738E92,$E3FFFF,$6E757E,$172024
	dc.l	$515C59,$614E49,$54443D,$553F33,$59473C,$423A33,$0E0E14,$3A3942
	dc.l	$57545D,$575763,$5A5C6E,$535976,$555D7B,$3B4263,$676C8D,$495664
	dc.l	$5C6267,$A1A8B1,$92A3B8,$517495,$739ABA,$6486A4,$7A98B5,$7593AE
	dc.l	$7696B3,$6787A4,$7696B3,$7A9AB7,$7392B1,$7796B5,$7796B5,$7291B0
	dc.l	$6688A6,$7296B4,$7696B3,$7997B4,$8198B8,$6F7BB1,$7079C3,$7277BC
	dc.l	$103F3C,$394448,$435058,$556772,$667585,$697686,$6F7D89,$6E7C88
	dc.l	$78858D,$3F484B,$5B6168,$666C77,$43515D,$202937,$98B7D8,$6C8BA2
	dc.l	$6F8E9D,$98A8B4,$72818A,$16333A,$A8D1D4,$457678,$05282B,$1A262A
	dc.l	$8E9898,$625D5E,$645854,$736356,$5A5143,$55554F,$4A4F52,$50535B
	dc.l	$1B1D27,$0E101A,$050610,$131625,$10182F,$445269,$79879A,$556572
	dc.l	$72787D,$868C97,$AEC0DD,$6A87AC,$88A9CA,$7599B7,$779CB8,$83A8C2
	dc.l	$6B8BA8,$6C8CA9,$7696B3,$7999B6,$7594B3,$7E9DBC,$6D8CAB,$6786A5
	dc.l	$6587A4,$6F91AF,$7796B5,$7291B2,$7F9ABC,$6C7CB1,$6D78C2,$7073AA
	dc.l	$284843,$2E3E3D,$5F6E70,$718487,$717E8C,$788294,$6E7889,$697384
	dc.l	$788490,$555E62,$373F46,$717980,$69737A,$00040B,$9CC0D0,$578596
	dc.l	$224D5C,$8CB4CD,$88A4C7,$9DC3E1,$ADD7EA,$1E484F,$608D90,$34454E
	dc.l	$101926,$768692,$EFF8FF,$585D60,$4A4F52,$333F45,$718CA7,$7A8A9B
	dc.l	$323539,$4B4D58,$000118,$272E3F,$4D5B71,$8496A7,$42515A,$706E6D
	dc.l	$7D8D99,$9AB8D5,$9FBFE2,$6685A6,$86A5C4,$8EAECB,$89ACC6,$6E91AB
	dc.l	$7392B1,$7190AF,$7594B3,$809FBE,$6F8FAC,$7191AE,$7191AE,$87A7C4
	dc.l	$7291B0,$6B8AA9,$7D9AB9,$7E9BBA,$708BAD,$363B54,$3C354A,$413A4F
	dc.l	$7E9FB2,$6F8A9E,$668495,$7D9FAF,$7797A2,$79969F,$7E9BA4,$739399
	dc.l	$6C8992,$6F8C95,$6B8792,$5D7984,$637F8A,$5C6775,$7F99B1,$82A7C9
	dc.l	$8EB2D8,$8CB5D6,$95B2D9,$98BCE0,$93B8CE,$A4BEC5,$3E5C61,$5E6D76
	dc.l	$202937,$697684,$283D52,$6C7987,$464F58,$2A333C,$203A52,$8CA5BF
	dc.l	$697A8F,$7F8A9E,$566071,$637080,$7C8A9C,$5B6674,$90959E,$818B95
	dc.l	$95B0CA,$87AED4,$8BAFD3,$7190B1,$7A99B8,$85A5C2,$7A9BB5,$6F90AA
	dc.l	$6685A4,$7A99B8,$6988A7,$6988A7,$6A8AA7,$7A9AB7,$7595B2,$6E8EAB
	dc.l	$7C99B8,$7390AF,$6B88A7,$7491B0,$718DAB,$646671,$706361,$6C6169
	dc.l	$807E7E,$857D7D,$B1AAA7,$ACA9A4,$C4C4CA,$C2C3CD,$BABBC5,$B9BBC3
	dc.l	$B9BCC4,$B8C0C7,$ABB2BB,$A1A8B1,$99A0A9,$848F97,$32475C,$7490B3
	dc.l	$8AA8D1,$8CB2D4,$9EBBE2,$91B5D9,$9DBFD6,$6E7A84,$C2D5DC,$4C5D66
	dc.l	$50606D,$435360,$8EA9C4,$324253,$323D45,$343E45,$4D6172,$7B9BB8
	dc.l	$527498,$6C839D,$1B2836,$6D808D,$4F5F6C,$5F6973,$7B8089,$839DBB
	dc.l	$85ABCE,$82ABD2,$8BACD3,$557495,$7998B7,$62829F,$88A9C3,$7B9CB6
	dc.l	$7493B2,$6887A6,$7493B2,$7897B6,$6787A4,$7595B2,$7F9FBC,$7292AF
	dc.l	$819FBC,$7593B0,$6684A1,$7391AE,$6F8CA7,$71757A,$746862,$6C6163
	dc.l	$19505D,$346071,$6F8EA5,$97B2CD,$A2BBCF,$99B2C2,$A9C2D2,$A3BCCC
	dc.l	$8EA8B6,$96ACB7,$8DA3AE,$7B919C,$728893,$78888E,$738798,$6B88A3
	dc.l	$9DC2DE,$81A8C8,$7E9DC4,$83ABCE,$99B5CD,$C8C8D4,$96A3AB,$6E8A91
	dc.l	$577580,$1F3945,$5A6F84,$475462,$121B24,$08111A,$1A3248,$8BAECF
	dc.l	$82A9CF,$91B7D7,$92B3CD,$7594AD,$7D96AA,$718A9E,$8CA7BC,$789DC3
	dc.l	$759FC4,$82A9D0,$84A2CB,$537293,$6B8AA9,$6383A0,$8EAFC9,$7D9EB8
	dc.l	$7695B4,$7392B1,$7D9CBB,$6A89A8,$6D8DAA,$7696B3,$6686A3,$6E8EAB
	dc.l	$87A5C0,$89A7C2,$7290AB,$6F8DA8,$708CA4,$B1B1B1,$C0ADA0,$BEAAA5
	dc.l	$467878,$4A7774,$2A4450,$2D364A,$404058,$2B2841,$2B2F4B,$212645
	dc.l	$2A2D4C,$292951,$2A2E51,$2D2D55,$2E2E4C,$253046,$283456,$657FA4
	dc.l	$AED0F4,$A6CDED,$92B6DA,$6D93B5,$B4CFE4,$FDFBFF,$53626B,$3E5E64
	dc.l	$396069,$93B3C0,$24333C,$091013,$3F454C,$2E3741,$89A9C6,$7BA1C3
	dc.l	$88ABCC,$95BDE0,$8EBAE3,$6E94B7,$7FA3C1,$97BFDC,$74A3C3,$769CBE
	dc.l	$7DA3C5,$88ACD0,$8AA8D1,$587699,$708FAE,$60809D,$8DAEC8,$6586A0
	dc.l	$6F8EAD,$89A8C7,$708FAE,$6988A7,$7D9DBA,$6787A4,$7696B3,$62829F
	dc.l	$7894B2,$708FA4,$6A859F,$35506B,$85A3B6,$ADA1A1,$C8AE9E,$CCB0A9
	dc.l	$293C69,$254B57,$314D65,$2B324B,$FBFDFF,$FFFFFE,$27394A,$718BA9
	dc.l	$B6C8DF,$8295BB,$6B859D,$47537D,$E7F9FA,$F6F2FD,$5E6176,$7286A5
	dc.l	$9BBADB,$95B4D3,$91B4D6,$A0BCDB,$556376,$D0D3DB,$7F95A0,$79919D
	dc.l	$758A99,$374355,$1D3638,$494C43,$3B4049,$0A101D,$354B64,$77A6C6
	dc.l	$91B8DF,$87ABD1,$7DAACC,$84A6CA,$8DADD1,$80A0C4,$81A1C5,$79A2C2
	dc.l	$7CA1C3,$8BABCF,$7F9EC5,$537495,$7897B6,$5D7B98,$99B6D1,$68869F
	dc.l	$85A3C0,$718FAC,$8AA8C5,$7290AD,$7896B3,$819FBC,$718FAC,$87A5C2
	dc.l	$506085,$213D48,$6D7C96,$283456,$7095A3,$BFA6AA,$CEAFA0,$C9ACA3
	dc.l	$91A2C9,$565C73,$26243A,$444357,$FAF9FF,$FFFDFC,$283243,$8594AE
	dc.l	$9AA3B1,$404B6B,$4B5D68,$444B6C,$F4FFFF,$FFFDFF,$595D70,$798DAC
	dc.l	$93B2D3,$96B6D9,$91AFD2,$D9EFFF,$D5E5F5,$BACDD0,$51797E,$98B7C0
	dc.l	$4F5F6C,$8E8C9F,$ACBFC6,$44443E,$2B333A,$101A24,$63768B,$85B3D2
	dc.l	$7CA8CD,$4C7294,$84B3CF,$87A8CF,$97B6DD,$8FAED5,$7998BF,$90B4D8
	dc.l	$98BFE5,$7599C1,$91B3DE,$6384A5,$7A99B8,$7593B0,$7592AD,$68869F
	dc.l	$6E8CA9,$8CAAC7,$7391AE,$88A6C3,$7A98B5,$83A1BE,$6A88A5,$87A5C2
	dc.l	$404F6F,$678191,$8F9DB3,$9AA7C1,$7B9CAF,$C3A8AB,$CEAD9D,$CDAFA4
	dc.l	$4D5F6A,$4A4358,$41363E,$45444E,$F9FBFF,$FFFEFF,$323648,$6A7182
	dc.l	$9C9798,$5A525D,$5B5849,$716773,$FFFFFB,$FAFAFA,$757B88,$879CB8
	dc.l	$9FBDE0,$77A4C9,$77A0C1,$90B3C7,$467075,$2B5855,$9ABDC1,$36565C
	dc.l	$E1F7FF,$1F2B37,$657782,$707272,$8B9AAA,$8FA7BB,$35485D,$739BB8
	dc.l	$739AC0,$43617E,$618595,$87ACC6,$7FA4BE,$7BA0BA,$5B809A,$567193
	dc.l	$A8CDEF,$87AFD2,$7E9FC6,$5D7E9F,$7392B1,$84A2BF,$7E9BB6,$82A0B9
	dc.l	$8AA8C5,$8DABC8,$6D8BA8,$7E9CB9,$7B99B6,$6E8CA9,$7E9CB9,$6E8CA9
	dc.l	$78899E,$7288A1,$95A4B4,$9AAAB7,$83A1BA,$CAAEAE,$D5B4A1,$D0B0A3
	dc.l	$748675,$464C53,$313A30,$5A5C64,$FAFCFF,$FBF8FA,$464A5C,$808691
	dc.l	$FCF9F4,$403D53,$B6B7AD,$767186,$ECF2FD,$FBFCF8,$787E89,$788DA9
	dc.l	$9EBCDF,$99BFE9,$8AA5C7,$97AEBE,$597C7F,$ACD4D2,$EBF9FF,$546E74
	dc.l	$6E9499,$3A646B,$CDE4EC,$747D80,$7287A3,$9BBAE1,$5D7288,$779DBB
	dc.l	$8EABD0,$8793AF,$DDE9F3,$E1EEFC,$5F6C7A,$B3C0CE,$84919F,$657691
	dc.l	$91B2CC,$9CC3DF,$9BB8D7,$6887A6,$6A89A8,$7795B2,$89A6C1,$7997B0
	dc.l	$82A0BD,$7997B4,$94B2CF,$6D8BA8,$7997B4,$7795B2,$7391AE,$8CAAC7
	dc.l	$778A99,$6F81A0,$95A4AD,$98A8AE,$7895B0,$CFB1B0,$D5B4A0,$D1B2A3
	dc.l	$4E6560,$363642,$E6E0E1,$A8A7AB,$FFFBFF,$FAFFFF,$2D3346,$878797
	dc.l	$E1E1DB,$464359,$E5E5E5,$E6E3F2,$F5F8FF,$FFFEFD,$8B919C,$8298B1
	dc.l	$91AFCC,$7AA1C8,$B6D1E6,$2C4755,$AEC8D4,$657372,$CBDEE6,$6B858C
	dc.l	$C0DAE1,$748991,$293F45,$787178,$344F5D,$98BCDA,$334B67,$8AABD2
	dc.l	$8EB1DC,$7B97AF,$D2E4E3,$CCDAEC,$54617B,$C5D5DB,$E0E9ED,$E1F4FF
	dc.l	$9FBFE3,$7FA8C8,$84A2C5,$5F7E9F,$5F7E9D,$93B1CE,$6885A0,$6D8BA4
	dc.l	$7D9BB6,$8AA8C3,$87A5C0,$718FAA,$8FACC7,$7B98B3,$6D8AA5,$86A3BE
	dc.l	$778797,$788CA5,$94A0B2,$838A9B,$6D7E99,$B3A5AB,$DBB1A4,$CEB69A
	dc.l	$CADAD9,$413D50,$D9D2D9,$AEAAB5,$FFFDFF,$FDFFFE,$333841,$8D8C96
	dc.l	$D5D6CC,$443E55,$EAE8E7,$F3EFFB,$E8EBF0,$FFFEFD,$8D909E,$788CAB
	dc.l	$8EB2D6,$9EC7EE,$919CB0,$ADB8C6,$CFEFFA,$537B79,$314850,$46636A
	dc.l	$4F6C73,$DFF9FF,$8DA4B4,$C8E1EB,$406B74,$628196,$95B3CC,$89AFD2
	dc.l	$8BACD3,$788FA5,$D7E4E6,$CCDAEC,$53607A,$C8D8DE,$E2EBEF,$E7FAFF
	dc.l	$9CBCE0,$91BADA,$8BA9CC,$6C8BAC,$6887A6,$8AA8C5,$7C99B4,$A4C2DB
	dc.l	$6785A0,$7694AF,$8AA8C3,$819FBA,$7390AB,$819EB9,$7A97B2,$607D98
	dc.l	$4B5769,$4F627D,$919FB5,$223144,$7793B2,$505466,$5C4543,$DAC2AC
	dc.l	$2C2F33,$181427,$2B272D,$42404C,$E0DAE5,$8B8C88,$36343A,$35323B
	dc.l	$87887F,$443D52,$95928E,$C4BCC7,$E4E5E9,$FFFFFE,$90909E,$92A0BD
	dc.l	$8CAACD,$86ACCE,$D3DCEA,$AAB0BD,$7D9DA8,$66918E,$E2F7FF,$E4FFFF
	dc.l	$638087,$718B92,$51697F,$467583,$38616A,$536E7C,$9BBFD7,$93BBDE
	dc.l	$96B4D7,$7F94AA,$DBE9EF,$CDDBED,$57647E,$C3D3D9,$DCE5E9,$E5F8FF
	dc.l	$95B5D9,$7FA8C8,$88A6C9,$597899,$5A7998,$84A2BF,$7D9AB5,$63819A
	dc.l	$87A5C0,$718FAA,$708EA9,$93B1CC,$90ADC8,$7390AB,$7D9AB5,$7F9CB7
	dc.l	$37455B,$1B3252,$788EA7,$7D94AA,$5E7C9F,$061022,$383029,$D4B39F
	dc.l	$A5A3A3,$322D3C,$4B4A4E,$37343D,$342D3C,$3D3938,$100812,$040008
	dc.l	$242523,$1B1226,$130E0B,$241C27,$7D7F80,$C3C3C3,$8E8794,$898DA5
	dc.l	$8DA4BA,$7FA4BE,$8FA1AC,$8896A2,$7A929E,$ECFFFF,$5C6B74,$394E56
	dc.l	$4F666E,$97AAB2,$446273,$638E9D,$E2F6FF,$86A0AC,$7EA3BD,$93B5D9
	dc.l	$85A4C5,$738BA1,$C6D9E0,$CDDBED,$55627C,$DEEEF4,$EBF4F8,$E4F7FF
	dc.l	$96B6DA,$93BCDC,$AAC8EB,$6C8BAC,$809FBE,$96B4D1,$829FBA,$A0BED7
	dc.l	$809EB9,$7A98B3,$6B89A4,$8BA9C4,$7693AE,$7A97B2,$7693AE,$7592AD
	dc.l	$7E95AB,$6D8BAE,$758DA9,$89A0BA,$768CAF,$0E1316,$B1AA99,$DCB39A
	dc.l	$FFFDFF,$FFFCFE,$FBFFFF,$FAFEFF,$4A4C54,$525559,$565961,$454A53
	dc.l	$1B2128,$0B0B17,$0E0E14,$282933,$42444C,$4C444E,$27232E,$3B3E4C
	dc.l	$282F3E,$243B4A,$8DB4BC,$486770,$8698A3,$3A444E,$313D49,$67707D
	dc.l	$555B68,$2A4750,$7FADB8,$90AFC8,$1A3042,$6A8B9E,$7A9FC5,$80A4D2
	dc.l	$89AAD1,$667D93,$7B878B,$7D8596,$61667F,$7C898B,$8B9896,$8798A5
	dc.l	$93B3D0,$7297B9,$93ADCB,$6480A3,$7CA0BE,$779CB2,$7492AD,$627B9B
	dc.l	$8EACC7,$6785A0,$6D8BA6,$7B99B4,$7290AD,$6987A4,$7F9DBA,$85A3C0
	dc.l	$94B0CE,$7294B1,$7B9CB6,$778CA8,$000321,$4A443F,$D0B49C,$DAB39D
	dc.l	$FDF6FD,$FEFDFF,$F3F7F8,$32383F,$1F2328,$30373A,$5C646B,$575F66
	dc.l	$4E555E,$6D737A,$686E75,$5E646B,$686E75,$5E5D66,$5E6169,$3C404B
	dc.l	$1B2330,$A1A9B6,$4C6D76,$A2BFC8,$8999A5,$A1B5C0,$67848D,$B5C7D2
	dc.l	$777886,$445A65,$64898D,$A1B4C9,$657782,$061D2C,$1E3446,$0F263C
	dc.l	$556B7D,$48555D,$5F6260,$656876,$67687C,$747C7B,$78817E,$687D93
	dc.l	$96B9DB,$80A6D0,$9FBCE1,$6588AA,$7A95AF,$44586A,$5D758B,$5F819E
	dc.l	$6987A2,$7E9CB7,$6F8DA8,$6886A1,$718FAC,$6A88A5,$63819E,$7391AE
	dc.l	$7894B2,$7393B0,$85A4BD,$7D8EA9,$0F132B,$7F7369,$DDBB9E,$D6B19D
	dc.l	$E7E8EC,$FDFEFF,$4B4D55,$61666F,$6E7277,$22292C,$666E75,$575F66
	dc.l	$4A535C,$5B6168,$686E75,$6A7077,$4F555C,$50595D,$5F656C,$5B646D
	dc.l	$CDDCE5,$EAEAF8,$AFC3CE,$B8CED9,$9CAAB6,$2A434D,$547B83,$5B7881
	dc.l	$89919E,$586C77,$A8C1C3,$778193,$717A7E,$464F58,$12121E,$030412
	dc.l	$05091B,$010210,$08090D,$040610,$080818,$404744,$515657,$343E4F
	dc.l	$899FB8,$A6BEDC,$162845,$476784,$46546A,$3A3A4A,$69798A,$81A5BD
	dc.l	$7B99B4,$6F8DA8,$6E8CA7,$7B99B4,$7795B2,$6785A2,$6E8CA9,$7A98B5
	dc.l	$7996B1,$7492AF,$88A3BE,$93A1B8,$171826,$DAC6B4,$D1AB8B,$D8B19B
	dc.l	$151A1B,$DBDDE7,$848691,$71737D,$2C3035,$4E5558,$010910,$525A61
	dc.l	$667077,$6B7478,$596266,$525B5F,$697276,$686F72,$606469,$54646A
	dc.l	$416468,$8E94A1,$6F838E,$4A5E69,$5E6A76,$D2E6F1,$436870,$264D55
	dc.l	$79949E,$4A747B,$6C8085,$1A2638,$464F52,$3B4043,$212030,$0F0E1E
	dc.l	$0A0A1C,$00000F,$080B19,$3E424D,$606372,$697171,$4B4E5D,$262227
	dc.l	$02060B,$090D18,$161725,$000016,$0E1120,$3B3B41,$242D36,$89A1B3
	dc.l	$7E9CB7,$718FAA,$6F8DA8,$7492AD,$7B99B6,$86A4C1,$7492AF,$7D9BB8
	dc.l	$85A0BA,$718EAD,$8297B6,$10172B,$50494C,$D5B899,$DFB592,$D8B19B
	dc.l	$393F44,$6E727D,$616472,$3B4049,$41474C,$4A5154,$585E63,$2E363D
	dc.l	$646E75,$4E595D,$525D61,$657074,$5D686C,$54575B,$606568,$586B6E
	dc.l	$133A3C,$9FB0B9,$032029,$92A8B3,$28313E,$D1E3EE,$D4EFF9,$8EB5BD
	dc.l	$7EA3AB,$407278,$7E949F,$031123,$364145,$2A3035,$646F77,$5F6D73
	dc.l	$5E696D,$657175,$5F6B71,$4E5564,$555C6B,$5A646B,$3F4459,$252837
	dc.l	$060D1C,$000213,$9296AE,$151025,$3B3C46,$50595C,$323B3F,$3A4553
	dc.l	$7998AF,$7F9DB8,$91AFCA,$8AA7C2,$6E8CA9,$7E9CB9,$718FAC,$7B99B6
	dc.l	$7594AD,$6D89A8,$98AAC9,$15192B,$584B43,$E4C19F,$EABD9B,$D7B199
	dc.l	$1D3033,$5E6A6A,$5E5F5B,$4F4944,$696B6C,$5D656C,$59626B,$758187
	dc.l	$5C676B,$58616A,$636C75,$616A73,$5A636C,$6D6D73,$617073,$585E63
	dc.l	$435457,$C4D4E0,$587681,$C7D4E2,$3D4251,$445C68,$4F6975,$33575F
	dc.l	$6C969B,$6B9195,$34555E,$ABC0C8,$535F65,$4F5A5E,$4B575D,$48535B
	dc.l	$5D6870,$626D75,$667179,$606B73,$566169,$414C54,$657078,$656E7B
	dc.l	$666F7C,$666F7C,$67707E,$5E646F,$5E636C,$161822,$555761,$3B4049
	dc.l	$2D414C,$8098AE,$6785A2,$809CBA,$87A3C1,$8BA7C5,$7A96B4,$809CBA
	dc.l	$6995AD,$788FAF,$000C23,$171C1D,$D3BBA5,$DCB295,$DBB194,$D9AF92
	dc.l	$85907C,$C6C7B3,$D2BFAA,$D6B8A5,$695948,$6B6D6D,$526370,$495A63
	dc.l	$677171,$636C75,$535C65,$626B74,$68717A,$60636B,$576369,$757880
	dc.l	$5B6B71,$4C656F,$314D58,$314753,$566774,$8199A5,$899CA9,$698891
	dc.l	$144347,$6AA0A1,$194245,$5B797E,$B7CACF,$BDC9CF,$4D5860,$4E5961
	dc.l	$717C84,$67727A,$5E6971,$5C676F,$515C64,$4F5A62,$636E76,$616D73
	dc.l	$677379,$5D696F,$626D75,$37444C,$59646C,$63656F,$1D1E28,$2D2C36
	dc.l	$323B45,$67798A,$6E8CA5,$6D90AA,$6F8BA9,$7B97B5,$738FAD,$7C98B6
	dc.l	$779EBA,$7C8EAD,$091122,$4E4B46,$D4B69B,$DDB192,$DCB091,$DAAE8F
	dc.l	$ECB89A,$E8B99A,$E2B998,$E0BA98,$D2B093,$E8D2C0,$73706C,$434A4D
	dc.l	$59656B,$646D76,$59626B,$626B74,$666F78,$555A63,$636A73,$605F69
	dc.l	$54666D,$406C73,$254550,$57828B,$13444C,$96B2BD,$6A6F7E,$545C69
	dc.l	$EDFEFF,$D4F1F6,$566568,$6B797F,$E7ECF5,$F0ECF8,$686F78,$5F6A72
	dc.l	$4C575F,$4F5A62,$5B666E,$616C74,$606B73,$606B73,$505B63,$4F5B61
	dc.l	$647076,$5F6B71,$5F6B71,$536068,$505B63,$626972,$4E505A,$454650
	dc.l	$34363E,$3C454E,$7E94A6,$62859F,$7490AE,$6F8BA9,$718DAB,$7B97B5
	dc.l	$7392B3,$8A92AF,$0A0A10,$4F4331,$DBB291,$DEB190,$DDB08F,$DBAE8D
	dc.l	$DABA96,$DCB997,$E0BA98,$E4B899,$E2B699,$E5B591,$E1BFA1,$C0B8B1
	dc.l	$5A6979,$606972,$646D76,$5D666F,$69727B,$5C626D,$6A6E79,$766F7C
	dc.l	$667780,$456872,$EDF6FF,$7B99A4,$D8FFFF,$506370,$6D8591,$A3B1BD
	dc.l	$EEF7FF,$202D35,$555C5F,$607174,$C3D5DC,$5D6673,$3C454F,$4F5A62
	dc.l	$5F6A72,$68737B,$626D75,$566169,$5C676F,$5C676F,$646F77,$5E6872
	dc.l	$4C5660,$4E5862,$606A74,$646D76,$5E656E,$4E5760,$5D6870,$606972
	dc.l	$45494E,$282C31,$2D3D4A,$5D7893,$7894B2,$7692B0,$7D99B7,$6985A3
	dc.l	$6983A7,$080B27,$464140,$D4C0A7,$E0B18B,$DDAF8D,$DCAE8C,$DBAD8B
	dc.l	$E3B897,$E3B897,$E3B897,$E3B897,$E8B797,$E6B797,$E1B897,$E0BB99
	dc.l	$C1AE93,$617576,$4B5E61,$62707C,$4D5A6A,$606368,$677276,$51656A
	dc.l	$A1BEC2,$577A7D,$96C6C8,$586E74,$FDFCFF,$79727F,$749EA5,$C2CBD8
	dc.l	$EAEBF9,$303E4A,$333F49,$535C66,$B7D1D8,$B6C9D1,$68717A,$475059
	dc.l	$626B74,$636C75,$636C75,$535C65,$49525B,$5F6871,$616A73,$636C75
	dc.l	$4F5861,$545D66,$59626B,$646D76,$666F78,$535C65,$555E67,$646E75
	dc.l	$212429,$494249,$373B40,$465B5D,$7899AD,$7B9CB6,$7590B2,$7087A7
	dc.l	$7F9DBA,$170C20,$383B2C,$DDAD91,$D5B58C,$DCAD8D,$DBAC8C,$D9AA8A
	dc.l	$E1B695,$E1B695,$E1B695,$E1B695,$E4B595,$E4B595,$E4B998,$DFB695
	dc.l	$E1B897,$DBAF92,$DCBA9D,$D1BDA4,$A39981,$777874,$7D7F7F,$5E6068
	dc.l	$888A95,$6E737C,$D3EDF3,$233944,$5A6D7A,$5A7785,$527F8D,$C0DBE9
	dc.l	$E7FBFF,$5E767C,$444E58,$6B747E,$628288,$415D64,$47525A,$6B747D
	dc.l	$646D76,$525B64,$48515A,$646D76,$636C75,$5B646D,$576069,$5C656E
	dc.l	$5C656E,$5D666F,$535C65,$4F5861,$626B74,$626B74,$5B646D,$4D595F
	dc.l	$4D585C,$2A2A30,$1C1A20,$283135,$3D5162,$718DA5,$7395B3,$7797B4
	dc.l	$798FA8,$1A121C,$BBB09C,$E3B798,$DAB08B,$D9AA8A,$D8A989,$D6A787
	dc.l	$E2B691,$E2B691,$E3B792,$E3B792,$E4B792,$E4B792,$E3B792,$E3B792
	dc.l	$E1B792,$DDB794,$E1B794,$E8B595,$EBB495,$E9B793,$E0B797,$D3B59C
	dc.l	$D4BCA8,$AEA598,$7E8479,$65625E,$6E696A,$445356,$959CAB,$63717D
	dc.l	$CFD9E3,$71767F,$5E6A74,$545D67,$2B484F,$455F66,$545D66,$717A83
	dc.l	$505962,$5A636C,$606972,$5B646D,$4F5861,$677079,$666F78,$59626B
	dc.l	$535C65,$576069,$5F6871,$69727B,$49525B,$505962,$576069,$5F6B71
	dc.l	$5A666A,$53595E,$131117,$3D3B41,$474B56,$889EB0,$6D8BA6,$7996B1
	dc.l	$060C1F,$3C3934,$D0AB91,$D1AC8A,$DEA889,$D7AA85,$D6A984,$D6A984
	dc.l	$E2B58F,$E2B58F,$E3B690,$E3B690,$E3B690,$E3B690,$E5B690,$E5B690
	dc.l	$E2B691,$DCB693,$DEB693,$E3B593,$E7B591,$D8BB8E,$DFB98F,$EAB692
	dc.l	$F5B898,$F1B494,$DDB494,$CFB097,$CFBEA9,$94AA98,$626867,$BDDCDB
	dc.l	$36575A,$576C74,$66757E,$4A535D,$859AA2,$65717B,$545B64,$565F68
	dc.l	$656E77,$5D666F,$505962,$6A737C,$68717A,$4E5760,$616A73,$6A737C
	dc.l	$5C656E,$4E5760,$565F68,$5F6871,$646D76,$535C65,$565F68,$5D676E
	dc.l	$666F73,$5D6368,$4C4F54,$4D4B51,$3E3C42,$394959,$6E859F,$8997B4
	dc.l	$191122,$3F3F33,$DDAA8A,$CEAC88,$E2A689,$D6A983,$D5A882,$D4A781
	dc.l	$E0B38E,$E0B38E,$E1B48F,$E1B48F,$E1B48E,$E1B58C,$E2B68D,$E2B68D
	dc.l	$E4B68D,$E4B68D,$E2B68D,$E1B78D,$E1B78D,$E4B490,$E2B590,$E1B590
	dc.l	$DFB590,$E1B78D,$DFB88C,$E1B58C,$E1B28C,$B69E7A,$D3B5AA,$ABA4A9
	dc.l	$4A4249,$D7C6A5,$1C2921,$737C79,$627473,$758C8E,$54676F,$596975
	dc.l	$697985,$4E6169,$495861,$6A717A,$565B64,$63636F,$6F6D79,$656272
	dc.l	$5D5D6B,$60686F,$647074,$4D4F57,$514E57,$696773,$6A6874,$53535F
	dc.l	$585E65,$656A73,$696E77,$6A6C76,$504C52,$373944,$3B4354,$757B8E
	dc.l	$0B0D17,$C1B096,$DEAA85,$D7A987,$DDA784,$D5A581,$D4A480,$D4A480
	dc.l	$E1B18D,$E1B18D,$E2B28E,$E2B28E,$E2B38D,$E2B48B,$E3B58C,$E3B58C
	dc.l	$E3B58C,$E3B58C,$E3B58C,$E3B58C,$E3B58C,$E3B38F,$E3B38F,$E3B38F
	dc.l	$E3B38F,$E0B58E,$E0B68C,$DEB48A,$DFB58B,$DDB68F,$DFB49F,$747D7A
	dc.l	$E3ECF5,$E8B69F,$E0AC88,$EFB697,$F1BA9F,$DBA992,$C3B0A1,$4F4337
	dc.l	$B3A79B,$837A6D,$847D74,$646F6D,$465256,$52646B,$5A6E79,$465B63
	dc.l	$52636C,$616A77,$585E6B,$506269,$5D7274,$516566,$475B5C,$536467
	dc.l	$6B7079,$5E636C,$41464F,$81868F,$757079,$24202B,$33333F,$070715
	dc.l	$363839,$C4A586,$DCA883,$D7A785,$DAA77F,$D6A57F,$D5A47E,$D4A37D
	dc.l	$E0B08C,$E0B08C,$E1B18D,$E1B18D,$E1B28C,$E1B38A,$E2B48B,$E2B48B
	dc.l	$E2B48B,$E2B48B,$E2B48B,$E2B48B,$E2B48B,$E2B28E,$E2B28E,$E2B28E
	dc.l	$E2B28E,$E2B38D,$E0B48B,$E2B68D,$DFB38A,$DCB18A,$E4B599,$A99387
	dc.l	$E4E6F0,$AE8C86,$D6B685,$D7B083,$E3B88D,$D9B187,$D4AD87,$DDB592
	dc.l	$D9B18E,$DEB693,$DFBA98,$CAB49B,$C0B29F,$888479,$6E726C,$727974
	dc.l	$575F5F,$59656B,$606F78,$5B5E6C,$4F4F5B,$666470,$6B6A73,$52545C
	dc.l	$676C75,$676C75,$535861,$6C717A,$69666F,$221C27,$1B1520,$100A15
	dc.l	$544842,$CFA784,$DAA77F,$D5A583,$D8A57D,$D5A47E,$D4A37D,$D4A37D
	dc.l	$E0AE8A,$E0AE8A,$E1AF8B,$E1AF8B,$E2B18B,$E2B189,$E2B189,$E2B189
	dc.l	$E2B189,$E2B189,$E2B189,$E2B189,$E2B189,$E2B08C,$E2B08C,$E3B18D
	dc.l	$E3B18D,$E3B28C,$E1B38A,$E1B38A,$E1B38A,$DFB38A,$DAB589,$ECA78C
	dc.l	$FAEFEB,$7B7570,$DFB28D,$E5B18D,$E6B08D,$E5B18D,$E6B28A,$E6B289
	dc.l	$E6B289,$E6B289,$E8B388,$EBB285,$E7B287,$E1B08A,$D9AB89,$DAAD92
	dc.l	$D3B199,$CAB9A4,$9E9784,$68675D,$636964,$6B7876,$445655,$455659
	dc.l	$6F747D,$4E535C,$4D525B,$5F646D,$68717A,$3B3E46,$4D494F,$1C151A
	dc.l	$9E8473,$D8A47B,$D9A47F,$D1A282,$D6A47A,$D4A179,$D3A078,$D29F77
	dc.l	$E1AD88,$E1AD88,$E2AE89,$E2AE8A,$E3B088,$E3B088,$E3B088,$E3B088
	dc.l	$E3B088,$E3B088,$E3B088,$E3B088,$E3B088,$E3AF8A,$E3AF8A,$E4B08B
	dc.l	$E4B08B,$E2B189,$E2B189,$E2B189,$E2B189,$E7B089,$E6B889,$E1B187
	dc.l	$A9AA96,$C19994,$DEB18B,$E0B289,$E0B388,$DBB488,$DEB18B,$E0B08C
	dc.l	$E0B08C,$E0B08C,$DEB18C,$DAB18A,$DCB08B,$E0B08C,$E0AE8A,$E1B286
	dc.l	$E2B185,$E7AF86,$E6AB83,$E7A983,$E6AE8B,$D7A98A,$CEA890,$CBAF9E
	dc.l	$877B7B,$716B6C,$6F7172,$61686B,$546066,$515B62,$74787D,$2B282A
	dc.l	$C4A389,$D9A277,$D6A27A,$D0A07E,$D3A177,$D4A077,$D39F76,$D09C73
	dc.l	$E0AC84,$E0AC84,$E1AD85,$E1AD85,$E2AE86,$E2AE86,$E2AE86,$E2AE86
	dc.l	$E2AE86,$E2AE86,$E2AE86,$E3AF87,$E1AD85,$E1AF85,$E1AF85,$E1AF85
	dc.l	$E1AF85,$E2AF87,$E2AF87,$E2AF87,$E2AF87,$E0B086,$E2B086,$DEAE8C
	dc.l	$AF987E,$BD9F8C,$E3AF87,$E3AF87,$E3AF87,$E3AF87,$E3AF87,$E3AF87
	dc.l	$E2AE86,$E2AE86,$E2AE86,$E1AE86,$E1AE86,$E0AD85,$E0AD85,$E1AD85
	dc.l	$E1AD85,$E0AC84,$E0AC84,$E0AC84,$E0AC84,$DFAB83,$DFAB83,$DFAB83
	dc.l	$DBA97F,$D8AB85,$CDA686,$CEAC8F,$C9B397,$B1A391,$9A8D7F,$87755E
	dc.l	$CFA27C,$D5A178,$D4A077,$D4A077,$D29E75,$D19D75,$D09C74,$CE9A72
	dc.l	$DFAB83,$DFAB83,$E0AC84,$E0AC84,$E1AD85,$E1AD85,$E1AD85,$E1AD85
	dc.l	$E1AD85,$E1AD85,$E1AD85,$E2AE86,$E0AC84,$E0AD85,$E0AD85,$E0AD85
	dc.l	$E0AD85,$E1AE86,$E1AE86,$E1AE86,$E1AE86,$DFAE86,$E1AE86,$DBAE89
	dc.l	$D9BD9E,$C8A58B,$E2AE86,$E2AE86,$E2AE86,$E2AE86,$E1AD85,$E1AD85
	dc.l	$E0AC84,$E0AC84,$E0AC84,$DFAC84,$DFAC84,$DFAC84,$DFAC84,$E0AC84
	dc.l	$E0AC84,$DFAB83,$DFAB83,$DFAB83,$DFAB83,$DEAA82,$DEAA82,$DDAA82
	dc.l	$D9AC80,$DEAB80,$E5A77E,$E8A37B,$D5A172,$DAAC83,$D1A57C,$D9A87A
	dc.l	$D4A176,$D39F76,$D29E75,$D19D74,$D09C73,$CE9A72,$CD9971,$CD9971
	dc.l	$DEAA82,$DEAA82,$DFAB83,$DFAB83,$DFAB83,$DFAB83,$DFAB83,$DFAB83
	dc.l	$DFAB83,$E0AC84,$E0AC84,$DFAB83,$DFAB83,$DEAA85,$DEAA85,$DFAB86
	dc.l	$DFAB86,$DFAC84,$DFAC84,$DFAC84,$DFAC84,$DFAC84,$EAAA87,$ECAA87
	dc.l	$DBAC86,$E6A987,$E1AD85,$E1AD85,$E0AC84,$E0AC84,$DFAB83,$E1AD85
	dc.l	$DFAB83,$DFAB83,$DFAB83,$DDAA82,$DDAA82,$DDAA82,$DDAA82,$DFAB83
	dc.l	$DFAB83,$DEAA82,$DEAA82,$DDA981,$DDA981,$DCA880,$DCA880,$DEA782
	dc.l	$DCA384,$D9A382,$D2A580,$CDA47D,$DCA47B,$D7A37B,$D5A179,$D69F78
	dc.l	$D29E75,$D19D74,$D09C73,$CF9B72,$CE9A71,$CC9870,$CB976F,$CA966E
	dc.l	$DCA880,$DCA880,$DDA981,$DDA981,$DDA981,$DDA981,$DDA981,$DDA981
	dc.l	$DDA981,$DDA981,$DDA981,$DDA981,$DDA981,$DCA884,$DCA884,$DDA985
	dc.l	$DDA985,$DDA984,$DDAA82,$DCA981,$DCA981,$DAA981,$DFAA85,$E1AA83
	dc.l	$D5AB80,$DFAA7F,$DFAB83,$DFAB83,$DEAA82,$DEAA82,$DCA880,$DEAA82
	dc.l	$DCA880,$DCA880,$DCA880,$DAA77F,$DAA77F,$DAA77F,$DAA77F,$DCA880
	dc.l	$DCA880,$DBA77F,$DBA77F,$DAA67E,$DAA67E,$D9A57D,$D9A57D,$D9A57C
	dc.l	$D7A676,$D6A476,$D9A37A,$DCA179,$D5A07B,$D6A077,$D49E75,$D39C75
	dc.l	$D19D75,$CF9B72,$CD9970,$CC986F,$CB976E,$C9956D,$C8946C,$C7936B

*************************************************************************************
*
* variables used

LAB_VARS						* points to variables base

	OFFSET	0				* use relative addressing

angle		ds.w	1				* angle $0000 to $01FF
zoom		ds.w	1				* zoom $0000 to $01FF

offsetx	ds.w	1				* x origin
offsety	ds.w	1				* y origin

deltax	ds.w	1				* delta x
deltay	ds.w	1				* delta y

	END	start
